@@ -18,7 +18,7 @@ from superlinked.framework.common.dag.index_node import IndexNode
 from superlinked.framework.common.dag.node import Node
 from superlinked.framework.common.dag.schema_dag import SchemaDag
 from superlinked.framework.common.exception import InvalidStateException
-from superlinked.framework.common.schema.schema_object import SchemaObject
+from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 
 
 class Dag:
@@ -27,21 +27,21 @@ class Dag:
         self._index_node = self.__init_index_node(self.nodes)
         self.__check_for_node_id_duplication()
         self.dag_effects = dag_effects or set()
-        node_id_schema_map: dict[str, set[SchemaObject]] = self.__init_node_id_schema_map(self.nodes)
-        self.__schemas: set[SchemaObject] = self.__init_schemas(node_id_schema_map)
-        self.__schema_dag_map: dict[SchemaObject, SchemaDag] = self.__init_schema_schema_dag_map(
+        node_id_schema_map: dict[str, set[IdSchemaObject]] = self.__init_node_id_schema_map(self.nodes)
+        self.__schemas: set[IdSchemaObject] = self.__init_schemas(node_id_schema_map)
+        self.__schema_dag_map: dict[IdSchemaObject, SchemaDag] = self.__init_schema_schema_dag_map(
             self.__schemas, node_id_schema_map
         )
 
     @property
-    def schemas(self) -> set[SchemaObject]:
+    def schemas(self) -> set[IdSchemaObject]:
         return self.__schemas
 
     @property
     def index_node(self) -> IndexNode:
         return self._index_node
 
-    def project_to_schema(self, schema: SchemaObject) -> SchemaDag:
+    def project_to_schema(self, schema: IdSchemaObject) -> SchemaDag:
         if (dag := self.__schema_dag_map.get(schema)) is not None:
             return dag
         raise InvalidStateException(f"SchemaDag for the given schema ({schema._base_class_name}) doesn't exist.")
@@ -51,20 +51,22 @@ class Dag:
             return index_node
         raise InvalidStateException(f"{type(self).__name__} doesn't have an IndexNode.")
 
-    def __init_node_id_schema_map(self, nodes: list[Node]) -> dict[str, set[SchemaObject]]:
+    def __init_node_id_schema_map(self, nodes: list[Node]) -> dict[str, set[IdSchemaObject]]:
         return {node.node_id: node.schemas for node in nodes}
 
-    def __init_schemas(self, node_id_schema_map: dict[str, set[SchemaObject]]) -> set[SchemaObject]:
+    def __init_schemas(self, node_id_schema_map: dict[str, set[IdSchemaObject]]) -> set[IdSchemaObject]:
         return {schema for schemas in node_id_schema_map.values() for schema in schemas}
 
     def __init_schema_schema_dag_map(
         self,
-        schemas: set[SchemaObject],
-        node_id_schema_map: dict[str, set[SchemaObject]],
-    ) -> dict[SchemaObject, SchemaDag]:
+        schemas: set[IdSchemaObject],
+        node_id_schema_map: dict[str, set[IdSchemaObject]],
+    ) -> dict[IdSchemaObject, SchemaDag]:
         return {schema: self.__project_to_schema(schema, node_id_schema_map) for schema in schemas}
 
-    def __project_to_schema(self, schema: SchemaObject, node_id_schema_map: dict[str, set[SchemaObject]]) -> SchemaDag:
+    def __project_to_schema(
+        self, schema: IdSchemaObject, node_id_schema_map: dict[str, set[IdSchemaObject]]
+    ) -> SchemaDag:
         filtered_nodes = {node for node in self.nodes if schema in node_id_schema_map[node.node_id]}
         projected_parents = set(parent for node in filtered_nodes for parent in node.project_parents_to_schema(schema))
         return SchemaDag(
@@ -76,5 +78,7 @@ class Dag:
         node_ids = set()
         for node in self.nodes:
             if node.node_id in node_ids:
-                raise InvalidStateException(f"Node id: {node} is duplicated!")
+                raise InvalidStateException(
+                    "Node id is duplicated.", node_id=node.node_id, node_type=type(node).__name__
+                )
             node_ids.add(node._node_id)
