@@ -12,10 +12,13 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from __future__ import annotations
+
 from dataclasses import dataclass, field
 from datetime import timedelta
 
 from superlinked.framework.common.const import constants
+from superlinked.framework.common.exception import InvalidInputException
 
 
 @dataclass(frozen=True)
@@ -31,7 +34,7 @@ class PeriodTime:
     period_time: timedelta = field(init=True)
     weight: float = field(default=constants.DEFAULT_WEIGHT, init=True)
 
-    def __lt__(self, other: "PeriodTime") -> bool:
+    def __lt__(self, other: PeriodTime) -> bool:
         if not isinstance(other, PeriodTime):
             return NotImplemented
         if self.period_time != other.period_time:
@@ -43,7 +46,7 @@ class PeriodTime:
         Validate the PeriodTime after initialization.
         """
         if int(self.period_time.total_seconds()) <= 0:
-            raise ValueError(
+            raise InvalidInputException(
                 f"Period_time parameter must be a positive time period, at least 1 seconds. "
                 f"Got {self.period_time.__str__()} which is {int(self.period_time.total_seconds())} seconds."
             )
