@@ -14,7 +14,8 @@
 
 from superlinked.framework.common.dag.embedding_node import EmbeddingNode
 from superlinked.framework.common.dag.node import Node
-from superlinked.framework.common.schema.schema_object import SchemaField, SchemaObject
+from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
+from superlinked.framework.common.schema.schema_object import SchemaField
 from superlinked.framework.common.space.config.transformation_config import (
     TransformationConfig,
 )
@@ -26,6 +27,6 @@ class RecencyNode(EmbeddingNode[int, int]):
         parent: Node[int] | None,
         transformation_config: TransformationConfig[int, int],
         fields_for_identification: set[SchemaField],
-        schema: SchemaObject | None = None,
+        schema: IdSchemaObject | None = None,
     ) -> None:
         super().__init__([parent], transformation_config, fields_for_identification, schema)
