@@ -12,13 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from beartype.typing import Generic
+from beartype.typing import Generic, TypeVar
 
-from superlinked.framework.common.schema.id_schema_object import IdSchemaObjectT
-from superlinked.framework.common.schema.schema_object import SchemaObjectT
+from superlinked.framework.common.parser.data_parser import DataParser
+from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 from superlinked.framework.common.source.types import SourceTypeT
 
+SourceT = TypeVar("SourceT", bound="Source")
 
-class Source(Generic[IdSchemaObjectT, SourceTypeT]):
-    def __init__(self, schema: SchemaObjectT) -> None:
+
+class Source(Generic[SourceTypeT]):
+    def __init__(self, schema: IdSchemaObject, parser: DataParser[SourceTypeT]) -> None:
         self._schema = schema
+        self._parser: DataParser[SourceTypeT] = parser
+
+    @property
+    def parser(self) -> DataParser[SourceTypeT]:
+        return self._parser
