@@ -154,7 +154,7 @@ class TelemetryRegistry:
 
         constructor = self.METRIC_CONSTRUCTORS.get(metric_type)
         if not constructor:
-            raise NotImplementedException(f"unsupported metric type: {metric_type}")
+            raise NotImplementedException("Unsupported metric type.", metric_type=metric_type.value)
 
         metric = constructor(
             name=name, metric_type=metric_type, description=description, unit=unit, default_labels=self._default_labels
