@@ -16,7 +16,7 @@ from superlinked.framework.common.dag.aggregation_node import AggregationNode
 from superlinked.framework.common.dag.effect_modifier import EffectModifier
 from superlinked.framework.common.dag.node import Node
 from superlinked.framework.common.data_types import Vector
-from superlinked.framework.common.exception import InitializationException
+from superlinked.framework.common.exception import InvalidStateException
 from superlinked.framework.common.interface.weighted import Weighted
 from superlinked.framework.common.space.config.aggregation.aggregation_config import (
     AggregationInputT,
@@ -42,7 +42,7 @@ class AggregationNodeUtil:
         effect_modifier: EffectModifier,
     ) -> AggregationNode[AggregationInputT, EmbeddingInputT]:
         if len(aggregation_effect_group.effects) == 0:
-            raise InitializationException("AggregationNode initialization needs a non-empty set of Effects.")
+            raise InvalidStateException("AggregationNode initialization needs a non-empty set of Effects.")
         event_aggregation_effect_groups = EventAggregationEffectGroup.group_by_event_and_affecting_schema(
             aggregation_effect_group.effects
         )
