@@ -20,27 +20,20 @@ from typing_extensions import override
 from superlinked.framework.common.exception import InvalidInputException
 from superlinked.framework.common.parser.data_parser import DataParser
 from superlinked.framework.common.parser.json_parser import JsonParser
-from superlinked.framework.common.schema.id_schema_object import (
-    IdSchemaObject,
-    IdSchemaObjectT,
-)
+from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
 from superlinked.framework.common.source.types import SourceTypeT
 from superlinked.framework.common.util.type_validator import TypeValidator
 from superlinked.framework.online.source.online_source import OnlineSource
 
 
-class InteractiveSource(OnlineSource[IdSchemaObjectT, SourceTypeT], Generic[IdSchemaObjectT, SourceTypeT]):
+class InteractiveSource(OnlineSource[SourceTypeT], Generic[SourceTypeT]):
     """
     InteractiveSource represents a source of data, where you can put your data. This will supply
     the index with the data it needs to index and search in.
     """
 
     @TypeValidator.wrap
-    def __init__(
-        self,
-        schema: IdSchemaObjectT,
-        parser: DataParser[IdSchemaObjectT, SourceTypeT] | None = None,
-    ) -> None:
+    def __init__(self, schema: IdSchemaObject, parser: DataParser[SourceTypeT] | None = None) -> None:
         """
         Initialize the InteractiveSource.
 
@@ -54,10 +47,7 @@ class InteractiveSource(OnlineSource[IdSchemaObjectT, SourceTypeT], Generic[IdSc
         if not isinstance(schema, IdSchemaObject):
             raise InvalidInputException(f"Parameter `schema` is of invalid type: {schema.__class__.__name__}")
 
-        super().__init__(
-            schema,
-            cast(DataParser[IdSchemaObjectT, SourceTypeT], parser or JsonParser(schema)),
-        )
+        super().__init__(schema, cast(DataParser[SourceTypeT], parser or JsonParser(schema)))
         self.__can_accept_data = False
 
     def allow_data_ingestion(self) -> None:
