@@ -31,7 +31,6 @@ from superlinked.framework.common.parser.parsed_schema import (
     ParsedSchemaWithEvent,
 )
 from superlinked.framework.common.schema.id_schema_object import IdSchemaObject
-from superlinked.framework.common.schema.schema_object import SchemaObject
 from superlinked.framework.common.storage_manager.storage_manager import StorageManager
 from superlinked.framework.common.telemetry.telemetry_registry import telemetry
 from superlinked.framework.dsl.index.index import Index
@@ -54,16 +53,14 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
         self.evaluator = evaluator
         self.context = context
         self.storage_manager = storage_manager
-        self.effect_schemas = set(index._effect_schemas)
-        self._schema_type_schema_mapper = index._schema_type_schema_mapper
-        self._dag_effects = index._dag_effects
-        self._mandatory_field_names_by_schema: Mapping[SchemaObject, Sequence[str]] = (
+        self._index = index
+        self._mandatory_field_names_by_schema: Mapping[IdSchemaObject, Sequence[str]] = (
             self._init_mandatory_field_names_by_schema(index)
         )
 
-    def _init_mandatory_field_names_by_schema(self, index: Index) -> defaultdict[SchemaObject, list[str]]:
-        mandatory_field_names_by_schema: defaultdict[SchemaObject, list[str]] = defaultdict(list)
-        id_field_names_by_schema: dict[SchemaObject, str] = {
+    def _init_mandatory_field_names_by_schema(self, index: Index) -> defaultdict[IdSchemaObject, list[str]]:
+        mandatory_field_names_by_schema: defaultdict[IdSchemaObject, list[str]] = defaultdict(list)
+        id_field_names_by_schema: dict[IdSchemaObject, str] = {
             schema: schema.id.name for schema in index.schemas if isinstance(schema, IdSchemaObject)
         }
         for field in index.non_nullable_fields:
@@ -83,7 +80,7 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
         event_msgs = []
         regular_msgs = []
         for message in messages:
-            if message.schema in self.effect_schemas:
+            if message.schema in self._index._effect_schemas:
                 event_msgs.append(cast(EventParsedSchema, message))
             else:
                 regular_msgs.append(message)
@@ -116,7 +113,10 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
             },
         ):
             self.storage_manager.write_combined_ingestion_result(
-                regular_msgs, online_entity_cache.changes, online_entity_cache.origin_ids
+                regular_msgs,
+                online_entity_cache.changes,
+                online_entity_cache.origin_ids,
+                self._index._fields_to_exclude,
             )
         logger.info(
             "stored input data",
@@ -157,7 +157,7 @@ class OnlineDataProcessor(Subscriber[ParsedSchema]):
         return dict(effect_to_parsed_schemas)
 
     def _get_matching_effects(self, event_schema: EventParsedSchema) -> list[DagEffect]:
-        return [effect for effect in self._dag_effects if effect.event_schema == event_schema.schema]
+        return [effect for effect in self._index._dag_effects if effect.event_schema == event_schema.schema]
 
     def _map_effect_group_to_parsed_schemas(
         self, effect_to_parsed_schemas: Mapping[DagEffect, Sequence[ParsedSchemaWithEvent]]
